@@ -82,19 +82,19 @@ def parse_folder(
             references_rv.update(found_references)
 
     # Any duplicate layers can be removed 
-    cleaned_resources_rv = _deduplicate_layers_from_resource_list(resources_rv)
+    cleaned_resources_rv = _deduplicate_resources_list(resources_rv)
 
     return cleaned_resources_rv, references_rv
 
 
-def _deduplicate_layers_from_resource_list(resources: List[Resource]) -> List[Resource]:
+def _deduplicate_resources_list(resources: List[Resource]) -> List[Resource]:
     """Remove duplicated layer resources
 
     Args:
         resources (List[Resource]): Sorted List of resources by x.hash
 
     Returns:
-        resource (List[Resources]): List with duplicate layers removed
+        resource (List[Resources]): List with duplicate resources removed
 
     Since multiple functions can produce the same Layer resource by referencing the same 
     3rd party resource, we need to deduplicate the layers from the list.
@@ -104,10 +104,7 @@ def _deduplicate_layers_from_resource_list(resources: List[Resource]) -> List[Re
         if i+1 >= len(resources):
             break
 
-        if not (resources[i].ruuid == LAMBDA_LAYER_RUUID and resources[i+1].ruuid == LAMBDA_LAYER_RUUID):
-            continue
-
-        if resources[i].hash == resources[i+1].hash:
+        if (resources[i].hash == resources[i+1].hash) and (resources[i].ruuid == resources[i+1].ruuid) and (resources[i].name == resources[i+1].name):
             resources.pop(i)
 
 
@@ -270,7 +267,6 @@ def _parse_serverless_functions(
     for parsed_function in parsed_file_info.parsed_functions:
 
         previous_info = handler_name_to_info.get(parsed_function.name)
-
         needed_module_information = package_mananger.get_top_level_module_info(
             parsed_function.imported_packages, filepath, previous_info.platform, download_cache
         )
@@ -294,6 +290,10 @@ def _parse_serverless_functions(
         # Update the seen packages 
         if dependencies_info:
             # Helps return only one copy of each layer for the file
+            # change the path of the artifact to a relative path to the workspace
+            for dependency in dependencies_info:
+                dependency.artifact_path = paths.get_relative_to_workspace_path(dependency.artifact_path)
+
             seen_layers.update(
               {x.hash:x.render() for x in dependencies_info}
             )
@@ -308,7 +308,7 @@ def _parse_serverless_functions(
 
         new_function = SimpleFunction(
             cdev_name=previous_info.name,
-            filepath=paths.get_full_path_from_workspace_base(handler_archive_path),
+            filepath=paths.get_relative_to_workspace_path(handler_archive_path),
             events=previous_info.events,
             configuration=new_configuration,
             function_permissions=previous_info.granted_permissions,
